@@ -10,7 +10,7 @@ import copy
 import itertools as it
 import subprocess
 import warnings
-from typing import Any, Callable, Dict, List, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union, cast
 
 import libsbml
 import numpy as np
@@ -26,7 +26,10 @@ from ...core import (
 )
 from ...core.utils import convert_id_to_sbml
 from ...typing import Array, ArrayLike
-from . import LabelModel, _AbstractRateModel
+from . import _AbstractRateModel
+
+if TYPE_CHECKING:
+    from . import LabelModel, LinearLabelModel
 
 
 class Model(_AbstractRateModel, BaseModel):
@@ -574,7 +577,9 @@ class Model(_AbstractRateModel, BaseModel):
                 )
         return lm
 
-    def to_linear_labelmodel(self, labelcompounds: Dict[str, int], labelmaps: Dict[str, List[int]]) -> Any:
+    def to_linear_labelmodel(
+        self, labelcompounds: Dict[str, int], labelmaps: Dict[str, List[int]]
+    ) -> LinearLabelModel:
         """Create a LinearLabelModel from this model.
 
         Watch out that for a linear label model reversible reactions have to be split
