@@ -659,8 +659,18 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         s.update_parameter(parameter_name=parameter_name, parameter_value=parameter_value)
         t, y = s.simulate_to_steady_state(tolerance=tolerance, **integrator_kwargs)
         if t is None or y is None:
-            concentrations = dict(zip(m.get_all_compounds(), np.full(len(m.get_all_compounds()), np.NaN)))
-            fluxes = dict(zip(m.get_rate_names(), np.full(len(m.get_rate_names()), np.NaN)))
+            concentrations = dict(
+                zip(
+                    m.get_all_compounds(),  # type: ignore
+                    np.full(len(m.get_all_compounds()), np.NaN),  # type: ignore
+                ),
+            )
+            fluxes = dict(
+                zip(
+                    m.get_rate_names(),  # type: ignore
+                    np.full(len(m.get_rate_names()), np.NaN),  # type: ignore
+                ),
+            )
             return parameter_value, concentrations, fluxes
         if include_fluxes:
             fluxes = dict(s.get_fluxes_df(concatenated=True).iloc[-1])  # type: ignore
